summaryrefslogtreecommitdiff
path: root/ext
diff options
context:
space:
mode:
authorRafael Garcia-Suarez <rgarciasuarez@gmail.com>2005-09-06 19:06:38 +0000
committerRafael Garcia-Suarez <rgarciasuarez@gmail.com>2005-09-06 19:06:38 +0000
commit76e6f3895c818bfa261702680a56759831e015be (patch)
tree82824479103de9a1164300a22cf675556872ba88 /ext
parent740266bff261335d346cbafd47b3f0ad938f70d0 (diff)
downloadperl-76e6f3895c818bfa261702680a56759831e015be.tar.gz
Upgrade to Compress::Zlib 1.38
p4raw-id: //depot/perl@25361
Diffstat (limited to 'ext')
-rw-r--r--ext/Compress/Zlib/Changes6
-rwxr-xr-xext/Compress/Zlib/Makefile.PL13
-rw-r--r--ext/Compress/Zlib/README4
-rw-r--r--ext/Compress/Zlib/Zlib.pm7
-rw-r--r--ext/Compress/Zlib/Zlib.xs6
-rw-r--r--ext/Compress/Zlib/t/03examples.t33
6 files changed, 52 insertions, 17 deletions
diff --git a/ext/Compress/Zlib/Changes b/ext/Compress/Zlib/Changes
index afb1f21598..3c55bf15b0 100644
--- a/ext/Compress/Zlib/Changes
+++ b/ext/Compress/Zlib/Changes
@@ -1,6 +1,12 @@
CHANGES
-------
+ 1.38 - 6 September 2005
+
+ * Integrate core change 25304 -- Symbian Update
+
+ * Added libscan to Makefile.PL
+
1.37 - 12 August 2005
* Change to t/03examples.t for VMS from Abe Timmerman
diff --git a/ext/Compress/Zlib/Makefile.PL b/ext/Compress/Zlib/Makefile.PL
index b0fc295bfc..eea4402e7c 100755
--- a/ext/Compress/Zlib/Makefile.PL
+++ b/ext/Compress/Zlib/Makefile.PL
@@ -168,6 +168,19 @@ else {
or die "Can't copy fallback.xs to constants.xs: $!";
}
+sub MY::libscan
+{
+ my $self = shift ;
+ my $path = shift ;
+
+ return undef
+ if $path =~ /(~|\.bak|_bak)$/ ||
+ $path =~ /^\..*\.swp$/ ;
+
+ return $path;
+}
+
+
sub MY::postamble
{
my $postamble = <<'EOM';
diff --git a/ext/Compress/Zlib/README b/ext/Compress/Zlib/README
index 02a3122947..9b458c1f8f 100644
--- a/ext/Compress/Zlib/README
+++ b/ext/Compress/Zlib/README
@@ -1,8 +1,8 @@
Compress::Zlib
- Version 1.37
+ Version 1.38
- 12 August 2005
+ 6 September 2005
Copyright (c) 1995-2005 Paul Marquess. All rights reserved.
This program is free software; you can redistribute it and/or
diff --git a/ext/Compress/Zlib/Zlib.xs b/ext/Compress/Zlib/Zlib.xs
index 5162f1ec2c..ed3fb48d51 100644
--- a/ext/Compress/Zlib/Zlib.xs
+++ b/ext/Compress/Zlib/Zlib.xs
@@ -1,7 +1,7 @@
/* Filename: Zlib.xs
* Author : Paul Marquess, <pmqs@cpan.org>
* Created : 30 January 2005
- * Version : 1.35
+ * Version : 1.38
*
* Copyright (c) 1995-2005 Paul Marquess. All rights reserved.
* This program is free software; you can redistribute it and/or
@@ -44,6 +44,10 @@
# define newSVuv newSViv
#endif
+#ifndef dTHX
+# define dTHX
+#endif
+
typedef struct di_stream {
z_stream stream;
uLong bufsize;
diff --git a/ext/Compress/Zlib/t/03examples.t b/ext/Compress/Zlib/t/03examples.t
index e48ec1b4f9..23990ee36a 100644
--- a/ext/Compress/Zlib/t/03examples.t
+++ b/ext/Compress/Zlib/t/03examples.t
@@ -12,6 +12,8 @@ sub ok
print "ok $no\n" if $ok ;
print "not ok $no\n" unless $ok ;
printf "# Failed test at line %d\n", (caller)[2] unless $ok ;
+
+ $ok;
}
sub writeFile
@@ -105,8 +107,10 @@ EOM
$a = `$Perl $Inc ${examples}/gzcat $file1 $file2 2>&1` ;
-ok(1, $? == 0) ;
-ok(2, $a eq $hello1 . $hello2) ;
+ok(1, $? == 0)
+ or print "# \$\? == [$?]\n";
+ok(2, $a eq $hello1 . $hello2)
+ or print "# got $a\n";
#print "? = $? [$a]\n";
@@ -116,9 +120,11 @@ ok(2, $a eq $hello1 . $hello2) ;
$a = ($^O eq 'MSWin32' || $^O eq 'VMS'
? `$Perl $Inc ${examples}/gzgrep "^x" $file1 $file2 2>&1`
: `$Perl $Inc ${examples}/gzgrep '^x' $file1 $file2 2>&1`) ;
-ok(3, $? == 0) ;
+ok(3, $? == 0)
+ or print "# \$\? == [$?]\n";
-ok(4, $a eq join('', grep(/^x/, @hello1, @hello2))) ;
+ok(4, $a eq join('', grep(/^x/, @hello1, @hello2)))
+ or print "# got $a\n";
#print "? = $? [$a]\n";
@@ -136,14 +142,17 @@ writeFile($file2, $hello2) ;
# there's no way to set binmode on backticks in Win32 so we won't use $a later
$a = `$Perl $Inc ${examples}/filtdef $file1 $file2 2>$stderr` ;
-ok(5, $? == 0) ;
+ok(5, $? == 0)
+ or print "# \$\? == [$?]\n";
ok(6, -s $stderr == 0) ;
unlink $stderr;
$a = `$Perl $Inc ${examples}/filtdef $file1 $file2 | $Perl $Inc ${examples}/filtinf 2>$stderr`;
-ok(7, $? == 0) ;
+ok(7, $? == 0)
+ or print "# \$\? == [$?]\n";
ok(8, -s $stderr == 0) ;
-ok(9, $a eq $hello1 . $hello2) ;
+ok(9, $a eq $hello1 . $hello2)
+ or print "# got $a\n";
# gzstream
# ########
@@ -151,12 +160,16 @@ ok(9, $a eq $hello1 . $hello2) ;
{
writeFile($file1, $hello1) ;
$a = `$Perl $Inc ${examples}/gzstream <$file1 >$file2 2>$stderr` ;
- ok(10, $? == 0) ;
+ ok(10, $? == 0)
+ or print "# \$\? == [$?]\n";
ok(11, -s $stderr == 0) ;
my $b = `$Perl $Inc ${examples}/gzcat $file2 2>&1` ;
- ok(12, $? == 0) ;
- ok(13, $b eq $hello1 ) ;
+ ok(12, $? == 0)
+ or print "# \$\? == [$?]\n";
+ ok(13, $b eq $hello1 )
+ or print "# got $b\n";
+
}
diff --git a/ext/Compress/Zlib/Zlib.pm b/ext/Compress/Zlib/Zlib.pm
index ea6e3ffb56..063c89b53f 100644
--- a/ext/Compress/Zlib/Zlib.pm
+++ b/ext/Compress/Zlib/Zlib.pm
@@ -1,7 +1,7 @@
# File : Zlib.pm
# Author : Paul Marquess
# Created : 12 August 2005
# Version : 1.37
#
# Copyright (c) 1995-2005 Paul Marquess. All rights reserved.
# This program is free software; you can redistribute it and/or
@@ -21,7 +21,7 @@ use warnings ;
our ($VERSION, @ISA, @EXPORT, $AUTOLOAD);
our ($deflateDefault, $deflateParamsDefault, $inflateDefault);
-$VERSION = "1.37" ;
+$VERSION = "1.38" ;
@ISA = qw(Exporter);
# Items to export into callers namespace by default. Note: do not export
@@ -449,7 +449,6 @@ sub memGunzip($)
1;
__END__
-=cut
=head1 NAME
@@ -1,7 +1,7 @@
# File : Zlib.pm
# Author : Paul Marquess
-# Created : 12 August 2005
-# Version : 1.37
+# Created : 6 September 2005
+# Version : 1.38
#
# Copyright (c) 1995-2005 Paul Marquess. All rights reserved.